Frame

Enum Frame 

enum Frame {
    Glycin(Frame),
    Texture(Texture),
}
A frame of an image.

Variants



Glycin(Frame)

A frame loaded via glycin.



Texture(Texture)

A texture in memory,

Implementations

Source

impl Frame

fn dimensions(&self) -> Option<FrameDimensions>

The dimensions of the frame.

fn is_animated(&self) -> bool

Whether the image that this frame belongs to is animated.

fn info(&self) -> BaseImageInfo

Get the BaseImageInfo for this frame.

fn generate_blurhash(self) -> Option<Blurhash>

Generate a Blurhash of this frame.

fn generate_thumbnail_and_blurhash( self, scale_factor: i32, renderer: &Renderer, ) -> Option<(Thumbnail, Blurhash)>

Generate a thumbnail and a Blurhash of this frame.

We use the thumbnail to compute the blurhash, which should be less expensive than using the original frame.