enum ImageDecoderSource {
Data(Vec<u8>),
File(File),
}Expand description
The source for decoding an image.
Variants
Data(Vec<u8>)
The bytes containing the encoded image.
File(File)
The file containing the encoded image.
Implementations
Sourceimpl ImageDecoderSource
impl ImageDecoderSource
Sourceconst MAX_DATA_SIZE: usize = 1_048_576
const MAX_DATA_SIZE: usize = 1_048_576
The maximum size of the Data variant. This is 1 MB.
Sourceasync fn with_bytes(bytes: Vec<u8>) -> Result<Self, MediaFileError>
async fn with_bytes(bytes: Vec<u8>) -> Result<Self, MediaFileError>
Construct an ImageSource from the given bytes.
If the size of the bytes are too big to be kept in memory, they are written to a temporary file.
Sourcefn into_loader(self) -> (Loader, Option<File>)
fn into_loader(self) -> (Loader, Option<File>)
Convert this image source into a loader.
Returns the created loader, and the image file, if any.
Sourceasync fn decode_image(
self,
request_dimensions: Option<FrameDimensions>,
) -> Result<Image, ImageError>
async fn decode_image( self, request_dimensions: Option<FrameDimensions>, ) -> Result<Image, ImageError>
Decode this image source into an Image.
Set request_dimensions if the image will be shown at specific
dimensions. To show the image at its natural size, set it to None.