pub(crate) enum ImageInfoLoader {
File(File),
Texture(Texture),
}Expand description
An API to load image information.
Variants
Implementations
Sourceimpl ImageInfoLoader
impl ImageInfoLoader
Sourceasync fn into_first_frame(self) -> Option<Frame>
async fn into_first_frame(self) -> Option<Frame>
Load the first frame for this source.
We need to load the first frame of an image so that EXIF rotation is applied and we get the proper dimensions.