pub(crate) struct ImageSource<'a> {
pub(crate) source: MediaSource<'a>,
pub(crate) info: Option<ImageSourceInfo<'a>>,
}Expand description
The source of an image.
Fields
source: MediaSource<'a>The source of the image.
info: Option<ImageSourceInfo<'a>>Information about the image.
Implementations
Sourceimpl ImageSource<'_>
impl ImageSource<'_>
Sourcefn should_thumbnail(
&self,
prefer_thumbnail: bool,
prefer_animated: bool,
thumbnail_dimensions: FrameDimensions,
) -> bool
fn should_thumbnail( &self, prefer_thumbnail: bool, prefer_animated: bool, thumbnail_dimensions: FrameDimensions, ) -> bool
Whether we should try to thumbnail this source for the given requested dimensions.
Sourcefn can_be_thumbnailed(&self) -> bool
fn can_be_thumbnailed(&self) -> bool
Whether this source can be thumbnailed by the media repo.
Returns false in these cases:
- The image is encrypted, because it is not possible for the media repo to make a thumbnail.
- The image uses the SVG format, because media repos usually do not accept to create a thumbnail of those.
Sourcefn dimensions(&self) -> Option<FrameDimensions>
fn dimensions(&self) -> Option<FrameDimensions>
The dimensions of this source.
Sourcefn is_animated(&self) -> bool
fn is_animated(&self) -> bool
Whether this source is animated.
Returns false if the info does not say that it is animated, or if the
MIME type is not one of the supported animated image formats.