pub(super) struct TextureThumbnailer(pub(super) Texture);Expand description
A thumbnailer for a GdkTexture.
Tuple Fields
0: TextureImplementations
Sourceimpl TextureThumbnailer
impl TextureThumbnailer
Sourcefn downscale_texture_if_needed(
self,
max_dimensions: FrameDimensions,
renderer: &Renderer,
) -> Option<Texture>
fn downscale_texture_if_needed( self, max_dimensions: FrameDimensions, renderer: &Renderer, ) -> Option<Texture>
Downscale the texture if needed to fit into the given maximum thumbnail dimensions.
Returns None if the dimensions of the texture are unknown.
Sourcefn texture_format_to_thumbnail_format(
format: MemoryFormat,
) -> Option<(MemoryFormat, PixelLayout)>
fn texture_format_to_thumbnail_format( format: MemoryFormat, ) -> Option<(MemoryFormat, PixelLayout)>
Convert the given texture memory format to the format needed to make a thumbnail.
The WebP encoder only supports RGB and RGBA.
Returns None if the format is unknown.
Sourcepub(super) fn generate_thumbnail_and_blurhash(
self,
scale_factor: i32,
renderer: &Renderer,
) -> Option<(Thumbnail, Blurhash)>
pub(super) fn generate_thumbnail_and_blurhash( self, scale_factor: i32, renderer: &Renderer, ) -> Option<(Thumbnail, Blurhash)>
Generate the thumbnail for the given scale factor, with the given
GskRenderer, and a Blurhash.
We use the thumbnail to compute the blurhash, which should be less expensive than using the original texture.