pub(crate) struct ThumbnailSettings {
pub(crate) dimensions: FrameDimensions,
pub(crate) method: Method,
pub(crate) animated: bool,
pub(crate) prefer_thumbnail: bool,
}Expand description
The settings for downloading a thumbnail.
Fields
dimensions: FrameDimensionsThe requested dimensions of the thumbnail.
method: MethodThe method to use to resize the thumbnail.
animated: boolWhether to request an animated thumbnail.
prefer_thumbnail: boolWhether we should prefer to get a thumbnail if dimensions are unknown.
This is particularly useful for avatars where we will prefer to save bandwidth and memory usage as we download a lot of them and they might appear several times on the screen. For media messages, we will on the contrary prefer to download the original content to reduce the space taken in the media cache.